%param_simulacion.m
%**************************************************************************
%Fichero con los parametros de la simulacion.
%**************************************************************************
%Dimensiones de la simulacion:
%*dim: 2=(x,y)
%
%Para integracion:
%*DeltaT: paso de intedracion en la simulacion.
%
%Para la funcion de optimizacion:
%*opciones_fmincon: conjunto de parametros segun la sintaxis de Matlab.
%
%Para la gestion del tamano de las matrices de resultados:
%*frec_aumento_matrices_resultados: cada cuandos ciclos aumentan las
%                                   matrices de resultados.
%*aumento_matrices_resultados: cuanto aumentan las matrices de resultados
%                              cada vez que aumentan.
%
%Para la entrada a ejecucion de los bloques de control del lider y resto:
%*frec_control_lider: cada cuantos ciclos se ejecuta el bloque de control
%                     del lider.
%*frec_control_seguidores: cada cuantos ciclos se ejecuta el bloque de 
%                          control del resto de robots.
%
%Para trazas e informacion por pantalla:
%*frec_traza_pantalla_h: cada cuantos ciclos se muestra por pantalla el 
%                        ciclo por el que se va en la ejecucion.
%*frec_traza_pantalla_tictoc: cada cuantos ciclos se muestra por pantalla
%                             la duracion de un ciclo de ejecucion.
%
%Para la gestion de un diario:
%*crear_diario: true/false
%*nombre_diario: nombre que toma el diario si se crea.
%
%Para salvar el workspace:
%salvar_worksape: true/false.
%
%Para generar un video por experimento:
%generar_video: true/false.
%
%Comienzo de numeracion  de experimentos:
%num_nombre_experimento: numero a partir del cual se numeraran los
%                        experimentos, incluido este, en el nombre.
%**************************************************************************

%Dimensiones de la simulacion:
dim = 2;

%Para integracion:
DeltaT=1e-4; 

%Para la funcion de optimizacion:
opciones_fmincon=optimset('Algorithm','active-set','Display','off');
%Opciones Display: 'off': no saca nada de salida.
%                  'notify': salida solo si no converge.
%                  'final': salida al final.
%                  'iter': salida en cada iteracion.

%Para la gestion del tamano de las matrices de resultados:
frec_aumento_matrices_resultados = 1000;
aumento_matrices_resultados = 1000;

%Para la entrada a ejecucion de los bloques de control del lider y resto:
frec_control_lider=1;
frec_control_seguidores=30;

%Para trazas e informacion por pantalla:
frec_traza_pantalla_h = 10;
frec_traza_pantalla_tictoc = 10;

%Para la gestion de un diario:
crear_diario= true;
nombre_diario = 'midiario.txt';

%Para salvar el workspace:
salvar_workspace=true;

%Para generar un video por experimento:
generar_video=true;

%Ruta para salidas:
ruta_salidas='.\Salidas\';
%ruta_salidas='F:\JM\Robots\Salidas\';

%Comienzo de numeracion  de experimentos:
num_nombre_experimento=93;
